@@ -64,7 +64,7 @@ def check_selector_items(items: Union[Tuple, List]) -> None:
 class Selector(Widget):
     """
     Selector widget: several items and two functions that are executed when changing
-    the selector (left/right) and pressing return key on the selected item.
+    the selector (left/right) and pressing return (apply) on the selected item.
 
     The items of the selector are like:
 
@@ -92,7 +92,7 @@ class Selector(Widget):
     :param selector_id: ID of the selector
     :param default: Index of default item to display
     :param onchange: Callback when changing the selector
-    :param onreturn: Callback when pressing return on the selector
+    :param onreturn: Callback when pressing return (apply) on the selector
     :param onselect: Function when selecting the widget
     :param style: Selector style (visual)
     :param style_fancy_arrow_color: Arrow color of fancy style
@@ -187,8 +187,7 @@ class Selector(Widget):
         self._style_fancy_bordercolor = style_fancy_bordercolor
         self._style_fancy_borderwidth = style_fancy_borderwidth
         self._style_fancy_box_inflate = style_fancy_box_inflate
-        self._style_fancy_box_margin = (int(style_fancy_box_margin[0]),
-                                        int(style_fancy_box_margin[1]))
+        self._style_fancy_box_margin = (int(style_fancy_box_margin[0]), int(style_fancy_box_margin[1]))
 
         # Apply default item
         default %= len(self._items)
@@ -250,10 +249,8 @@ class Selector(Widget):
 
             # Create arrows
             arrow_left = pygame.Rect(
-                int(title.get_width() + self._style_fancy_arrow_margin[0]
-                    + self._style_fancy_box_margin[0]),
-                int(self._style_fancy_arrow_margin[2]
-                    + self._style_fancy_box_inflate[1] / 2),
+                int(title.get_width() + self._style_fancy_arrow_margin[0] + self._style_fancy_box_margin[0]),
+                int(self._style_fancy_arrow_margin[2] + self._style_fancy_box_inflate[1] / 2),
                 title.get_height(),
                 title.get_height()
             )
@@ -304,8 +301,7 @@ class Selector(Widget):
             self._surface.blit(title, (0, int(self._style_fancy_box_inflate[1] / 2)))
             current_rect_bg = current.get_rect()
             current_rect_bg.x += title.get_width() + self._style_fancy_box_margin[0]
-            current_rect_bg.y += int(self._style_fancy_box_inflate[1] / 2
-                                     + self._style_fancy_box_margin[1])
+            current_rect_bg.y += int(self._style_fancy_box_inflate[1] / 2 + self._style_fancy_box_margin[1])
             current_rect_bg.width += 2 * (self._style_fancy_arrow_margin[0]
                                           + self._style_fancy_arrow_margin[1]
                                           + arrow_left.width)
@@ -521,7 +517,7 @@ class SelectorManager(AbstractWidgetManager, ABC):
         """
         Add a selector to the Menu: several items and two functions that are
         executed when changing the selector (left/right) and pressing return
-        button on the selected item.
+        (apply) on the selected item.
 
         The items of the selector are like:
 
@@ -605,7 +601,7 @@ class SelectorManager(AbstractWidgetManager, ABC):
         :param items: Item list of the selector; format ``[('Item1', a, b, c...), ('Item2', d, e, f...)]``
         :param default: Index of default item to display
         :param onchange: Callback executed when changing the selector
-        :param onreturn: Callback executed when pressing return button
+        :param onreturn: Callback executed when pressing return (apply)
         :param onselect: Callback executed when selecting the widget
         :param selector_id: ID of the selector
         :param style: Selector style (visual)
@@ -617,20 +613,13 @@ class SelectorManager(AbstractWidgetManager, ABC):
         attributes = self._filter_widget_attributes(kwargs)
 
         # Get fancy style attributes
-        style_fancy_arrow_color = kwargs.pop('style_fancy_arrow_color',
-                                             self._theme.widget_box_arrow_color)
-        style_fancy_arrow_margin = kwargs.pop('style_fancy_arrow_margin',
-                                              self._theme.widget_box_arrow_margin)
-        style_fancy_bgcolor = kwargs.pop('style_fancy_bgcolor',
-                                         self._theme.widget_box_background_color)
-        style_fancy_bordercolor = kwargs.pop('style_fancy_bordercolor',
-                                             self._theme.widget_box_border_color)
-        style_fancy_borderwidth = kwargs.pop('style_fancy_borderwidth',
-                                             self._theme.widget_box_border_width)
-        style_fancy_box_inflate = kwargs.pop('style_fancy_box_inflate',
-                                             self._theme.widget_box_inflate)
-        style_fancy_box_margin = kwargs.pop('style_fancy_box_margin',
-                                            self._theme.widget_box_margin)
+        style_fancy_arrow_color = kwargs.pop('style_fancy_arrow_color', self._theme.widget_box_arrow_color)
+        style_fancy_arrow_margin = kwargs.pop('style_fancy_arrow_margin', self._theme.widget_box_arrow_margin)
+        style_fancy_bgcolor = kwargs.pop('style_fancy_bgcolor', self._theme.widget_box_background_color)
+        style_fancy_bordercolor = kwargs.pop('style_fancy_bordercolor', self._theme.widget_box_border_color)
+        style_fancy_borderwidth = kwargs.pop('style_fancy_borderwidth', self._theme.widget_box_border_width)
+        style_fancy_box_inflate = kwargs.pop('style_fancy_box_inflate', self._theme.widget_box_inflate)
+        style_fancy_box_margin = kwargs.pop('style_fancy_box_margin', self._theme.widget_box_margin)
 
         widget = Selector(
             default=default,
